@@ -43,13 +43,13 @@
 
 struct _PtWaveviewerPrivate {
 	/* Wavedata */
-	gfloat	 *peaks;
-	gint64	  peaks_size;	/* size of array */
-	gint	  px_per_sec;
+	gfloat   *peaks;
+	gint64    peaks_size;	/* size of array */
+	gint      px_per_sec;
 	gint64    duration;	/* in milliseconds */
 
 	/* Properties */
-	gint64	  playback_cursor;
+	gint64    playback_cursor;
 	gboolean  follow_cursor;
 	gboolean  fixed_cursor;
 	gboolean  show_ruler;
@@ -122,7 +122,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (PtWaveviewer, pt_waveviewer, GTK_TYPE_SCROLLED_WINDO
 
 static gint64
 flip_pixel (PtWaveviewer *self,
-	    gint64        pixel)
+            gint64        pixel)
 {
 	/* In ltr layouts each pixel on the x-axis corresponds to a sample in the array.
 	   In rtl layouts this is flipped, e.g. the first pixel corresponds to
@@ -143,7 +143,7 @@ flip_pixel (PtWaveviewer *self,
 
 static gint64
 time_to_pixel (PtWaveviewer *self,
-	       gint64 ms)
+               gint64        ms)
 {
 	/* Convert a time in 1/1000 seconds to the closest pixel in the drawing area */
 	gint64 result;
@@ -159,7 +159,7 @@ time_to_pixel (PtWaveviewer *self,
 
 static gint64
 pixel_to_time (PtWaveviewer *self,
-	       gint64 pixel)
+               gint64        pixel)
 {
 	/* Convert a position in the drawing area to time in milliseconds */
 	gint64 result;
@@ -222,8 +222,8 @@ calculate_duration (PtWaveviewer *self)
 
 static gint64
 add_subtract_time (PtWaveviewer *self,
-		   gint          pixel,
-		   gboolean      stay_in_selection)
+                   gint          pixel,
+                   gboolean      stay_in_selection)
 {
 	/* add time to the cursor’s time so that the cursor is moved x pixels */
 
@@ -302,19 +302,24 @@ update_selection (PtWaveviewer *self)
 
 static gboolean
 pt_waveviewer_key_press_event (GtkWidget   *widget,
-			       GdkEventKey *event)
+                               GdkEventKey *event)
 {
-	PtWaveviewer *self = PT_WAVEVIEWER (widget);
+	PtWaveviewer    *self = PT_WAVEVIEWER (widget);
+	GdkModifierType  state;
+	guint            keyval;
 
-	if (event->type != GDK_KEY_PRESS)
+	if (gdk_event_get_event_type ((GdkEvent*) event) != GDK_KEY_PRESS)
 		return FALSE;
 
 	if (!self->priv->peaks)
 		return FALSE;
 
+	gdk_event_get_state ((GdkEvent*) event, &state);
+	gdk_event_get_keyval ((GdkEvent*) event, &keyval);
+
 	/* no modifier pressed */
-	if (!(event->state & ALL_ACCELS_MASK)) {
-		switch (event->keyval) {
+	if (!(state & ALL_ACCELS_MASK)) {
+		switch (keyval) {
 		case GDK_KEY_Escape:
 			self->priv->dragstart = self->priv->dragend = 0;
 			update_selection (self);
@@ -328,9 +333,9 @@ pt_waveviewer_key_press_event (GtkWidget   *widget,
 	if (self->priv->focus_on_cursor) {
 
 		/* no modifier pressed */
-		if (!(event->state & ALL_ACCELS_MASK)) {
+		if (!(state & ALL_ACCELS_MASK)) {
 
-			switch (event->keyval) {
+			switch (keyval) {
 			case GDK_KEY_Left:
 				g_signal_emit_by_name (self, "cursor-changed", add_subtract_time (self, -2, FALSE));
 				return TRUE;
@@ -353,9 +358,9 @@ pt_waveviewer_key_press_event (GtkWidget   *widget,
 		}
 		/* Only Control is pressed, not together with Shift or Alt
 		   Here we override the default horizontal scroll bindings */
-		else if ((event->state & ALL_ACCELS_MASK) == GDK_CONTROL_MASK) {
+		else if ((state & ALL_ACCELS_MASK) == GDK_CONTROL_MASK) {
 
-			switch (event->keyval) {
+			switch (keyval) {
 			case GDK_KEY_Left:
 				g_signal_emit_by_name (self, "cursor-changed", add_subtract_time (self, -2, TRUE));
 				return TRUE;
@@ -379,10 +384,10 @@ pt_waveviewer_key_press_event (GtkWidget   *widget,
 	} else {
 
 		/* No modifier pressed: Scroll window, depending on text direction */
-		if (!(event->state & ALL_ACCELS_MASK)) {
+		if (!(state & ALL_ACCELS_MASK)) {
 
 			GtkScrollType scroll = GTK_SCROLL_NONE;
-			switch (event->keyval) {
+			switch (keyval) {
 			case GDK_KEY_Left:
 				scroll = GTK_SCROLL_STEP_BACKWARD;
 				break;
@@ -416,8 +421,8 @@ pt_waveviewer_key_press_event (GtkWidget   *widget,
 
 static gboolean
 pointer_in_range (PtWaveviewer *self,
-		  gdouble       pointer,
-		  gint64        pos)
+                  gdouble       pointer,
+                  gint64        pos)
 {
 	/* Returns TRUE if @pointer (event->x) is not more than 3 pixels away from @pos */
 
@@ -426,7 +431,7 @@ pointer_in_range (PtWaveviewer *self,
 
 static void
 set_cursor (GtkWidget *widget,
-	    GdkCursor *cursor)
+            GdkCursor *cursor)
 {
 	GdkWindow  *gdkwin;
 	gdkwin = gtk_widget_get_window (widget);
@@ -435,32 +440,39 @@ set_cursor (GtkWidget *widget,
 
 static gboolean
 pt_waveviewer_button_press_event (GtkWidget      *widget,
-				  GdkEventButton *event)
+                                  GdkEventButton *event)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
+	GdkEventType         type;
+	GdkModifierType      state;
+	guint                button;
+	gdouble              x;
+	gint64               clicked;	/* the sample clicked on */
+	gint64               pos;	/* clicked sample’s position in milliseconds */
 
 	if (!self->priv->peaks)
 		return FALSE;
 
-	gint64 clicked;	/* the sample clicked on */
-	gint64 pos;	/* clicked sample’s position in milliseconds */
-
-	clicked = (gint) event->x;
+	type = gdk_event_get_event_type ((GdkEvent*)event);
+	gdk_event_get_state ((GdkEvent*) event, &state);
+	gdk_event_get_button ((GdkEvent*) event, &button);
+	gdk_event_get_coords ((GdkEvent*) event, &x, NULL);
+	clicked = (gint) x;
 	pos = pixel_to_time (self, clicked);
 
 
 	/* Single left click, no other keys pressed: new selection or changing selection */
-	if (event->type == GDK_BUTTON_PRESS
-	    && event->button == GDK_BUTTON_PRIMARY
-	    && !(event->state & ALL_ACCELS_MASK)) {
+	if (type == GDK_BUTTON_PRESS
+	    && button == GDK_BUTTON_PRIMARY
+	    && !(state & ALL_ACCELS_MASK)) {
 		/* set position as start and end point, for new selection */
 		self->priv->dragstart = self->priv->dragend = pos;
 
 		/* if over selection border: snap to selection border, changing selection */
-		if (pointer_in_range (self, event->x, self->priv->sel_start)) {
+		if (pointer_in_range (self, x, self->priv->sel_start)) {
 			self->priv->dragstart = self->priv->sel_end;
 			self->priv->dragend = self->priv->sel_start;
-		} else if (pointer_in_range (self, event->x, self->priv->sel_end)) {
+		} else if (pointer_in_range (self, x, self->priv->sel_end)) {
 			self->priv->dragstart = self->priv->sel_start;
 			self->priv->dragend = self->priv->sel_end;
 		}
@@ -471,9 +483,9 @@ pt_waveviewer_button_press_event (GtkWidget      *widget,
 	}
 
 	/* Single left click with Shift pressed and existing selection: enlarge selection */
-	if (event->type == GDK_BUTTON_PRESS
-	    && event->button == GDK_BUTTON_PRIMARY
-	    && (event->state & ALL_ACCELS_MASK) == GDK_SHIFT_MASK
+	if (type == GDK_BUTTON_PRESS
+	    && button == GDK_BUTTON_PRIMARY
+	    && (state & ALL_ACCELS_MASK) == GDK_SHIFT_MASK
 	    && self->priv->sel_start != self->priv->sel_end) {
 
 		self->priv->dragend = pos;
@@ -489,7 +501,7 @@ pt_waveviewer_button_press_event (GtkWidget      *widget,
 	}
 
 	/* Single right click: change cursor */
-	if (event->type == GDK_BUTTON_PRESS && event->button == GDK_BUTTON_SECONDARY) {
+	if (type == GDK_BUTTON_PRESS && button == GDK_BUTTON_SECONDARY) {
 		g_signal_emit_by_name (self, "cursor-changed", pos);
 		return TRUE;
 	}
@@ -499,12 +511,18 @@ pt_waveviewer_button_press_event (GtkWidget      *widget,
 
 static gboolean
 pt_waveviewer_scroll_event (GtkWidget      *widget,
-			    GdkEventScroll *event)
+                            GdkEventScroll *event)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
+	GdkModifierType      state;
+	gdouble              delta_x;
+	gdouble              delta_y;
+
+	gdk_event_get_state ((GdkEvent*) event, &state);
+	gdk_event_get_scroll_deltas ((GdkEvent*) event, &delta_x, &delta_y);
 
 	/* No modifier pressed: scrolling back and forth */
-	if (!(event->state & ALL_ACCELS_MASK)) {
+	if (!(state & ALL_ACCELS_MASK)) {
 		gtk_propagate_event
 			(gtk_scrolled_window_get_hscrollbar (GTK_SCROLLED_WINDOW (widget)),
 			(GdkEvent*)event);
@@ -512,12 +530,12 @@ pt_waveviewer_scroll_event (GtkWidget      *widget,
 	}
 
 	/* Only Control pressed: zoom in or out */
-	if ((event->state & ALL_ACCELS_MASK) == GDK_CONTROL_MASK) {
-		if (event->delta_y < 0 || event->delta_x < 0) {
+	if ((state & ALL_ACCELS_MASK) == GDK_CONTROL_MASK) {
+		if (delta_y < 0 || delta_x < 0) {
 			g_signal_emit_by_name (self, "zoom-out");
 			return TRUE;
 		}
-		if (event->delta_y > 0 || event->delta_x > 0) {
+		if (delta_y > 0 || delta_x > 0) {
 			g_signal_emit_by_name (self, "zoom-in");
 			return TRUE;
 		}
@@ -529,27 +547,30 @@ pt_waveviewer_scroll_event (GtkWidget      *widget,
 
 static gboolean
 pt_waveviewer_motion_notify_event (GtkWidget      *widget,
-				   GdkEventMotion *event)
+                                   GdkEventMotion *event)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
+	GdkModifierType      state;
+	gdouble              x;
+	gint64               clicked;	/* the sample clicked on */
+	gint64               pos;	/* clicked sample’s position in milliseconds */
 
 	if (!self->priv->peaks)
 		return FALSE;
 
-	gint64 clicked;	/* the sample clicked on */
-	gint64 pos;	/* clicked sample’s position in milliseconds */
-
-	clicked = (gint) event->x;
+	gdk_event_get_state ((GdkEvent*) event, &state);
+	gdk_event_get_coords ((GdkEvent*) event, &x, NULL);
+	clicked = (gint) x;
 	pos = pixel_to_time (self, clicked);
 
 	/* Right mouse button sets cursor */
-	if (event->state & GDK_BUTTON3_MASK) {
+	if (state & GDK_BUTTON3_MASK) {
 		g_signal_emit_by_name (self, "cursor-changed", pos);
 		return TRUE;
 	}
 
 	/* Left mouse button (with or without Shift key) sets selection */
-	if (event->state & GDK_BUTTON1_MASK || event->state & GDK_BUTTON1_MASK & GDK_SHIFT_MASK) {
+	if (state & GDK_BUTTON1_MASK || state & GDK_BUTTON1_MASK & GDK_SHIFT_MASK) {
 		self->priv->dragend = pos;
 		update_selection (self);
 		return TRUE;
@@ -557,8 +578,8 @@ pt_waveviewer_motion_notify_event (GtkWidget      *widget,
 
 	/* No button or any other button: change pointer cursor over selection border */
 	if (self->priv->sel_start != self->priv->sel_end) {
-		if (pointer_in_range (self, event->x, self->priv->sel_start)
-		    || pointer_in_range (self, event->x, self->priv->sel_end)) {
+		if (pointer_in_range (self, x, self->priv->sel_start)
+		    || pointer_in_range (self, x, self->priv->sel_end)) {
 			set_cursor (widget, self->priv->arrows);
 		} else {
 			set_cursor (widget, NULL);
@@ -570,9 +591,12 @@ pt_waveviewer_motion_notify_event (GtkWidget      *widget,
 
 static gboolean
 pt_waveviewer_button_release_event (GtkWidget      *widget,
-				    GdkEventButton *event)
+                                    GdkEventButton *event)
 {
-	if (event->button == GDK_BUTTON_PRIMARY) {
+	guint button;
+
+	gdk_event_get_button ((GdkEvent*) event, &button);
+	if (button == GDK_BUTTON_PRIMARY) {
 		set_cursor (widget, NULL);
 		return TRUE;
 	}
@@ -602,8 +626,8 @@ update_cached_style_values (PtWaveviewer *self)
 }
 
 static void
-pt_waveviewer_state_flags_changed (GtkWidget	 *widget,
-				   GtkStateFlags  flags)
+pt_waveviewer_state_flags_changed (GtkWidget     *widget,
+                                   GtkStateFlags  flags)
 {
 	update_cached_style_values (PT_WAVEVIEWER (widget));
 	GTK_WIDGET_CLASS (pt_waveviewer_parent_class)->state_flags_changed (widget, flags);
@@ -618,8 +642,8 @@ pt_waveviewer_style_updated (GtkWidget *widget)
 }
 
 static void
-pt_waveviewer_direction_changed (GtkWidget *widget,
-				 GtkTextDirection direction)
+pt_waveviewer_direction_changed (GtkWidget        *widget,
+                                 GtkTextDirection  direction)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
 	gint widget_width, first_visible, page_width;
@@ -658,8 +682,8 @@ stop_following_cursor (PtWaveviewer *self)
 
 static gboolean
 scrollbar_button_press_event_cb (GtkWidget      *widget,
-				 GdkEventButton *event,
-				 gpointer        data)
+                                 GdkEventButton *event,
+                                 gpointer        data)
 {
 	/* If user clicks on scrollbar don’t follow cursor anymore.
 	   Otherwise it would scroll immediately back again. */
@@ -672,8 +696,8 @@ scrollbar_button_press_event_cb (GtkWidget      *widget,
 
 static gboolean
 scrollbar_scroll_event_cb (GtkWidget      *widget,
-			   GdkEventButton *event,
-			   gpointer        data)
+                           GdkEventButton *event,
+                           gpointer        data)
 {
 	/* If user scrolls on scrollbar don’t follow cursor anymore.
 	   Otherwise it would scroll immediately back again. */
@@ -710,8 +734,8 @@ focus_lost (PtWaveviewer *self)
 
 static gboolean
 pt_waveviewer_focus_out_event (GtkWidget *widget,
-			       GdkEvent  *event,
-			       gpointer   data)
+                               GdkEvent  *event,
+                               gpointer   data)
 {
 	focus_lost (PT_WAVEVIEWER (widget));
 	return FALSE;
@@ -719,8 +743,8 @@ pt_waveviewer_focus_out_event (GtkWidget *widget,
 
 static gboolean
 pt_waveviewer_focus_in_event (GtkWidget *widget,
-			      GdkEvent  *event,
-			      gpointer   data)
+                              GdkEvent  *event,
+                              gpointer   data)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
 	if (!self->priv->focus_on_cursor && self->priv->peaks)
@@ -730,8 +754,8 @@ pt_waveviewer_focus_in_event (GtkWidget *widget,
 
 static gboolean
 pt_waveviewer_focus (GtkWidget        *widget,
-		     GtkDirectionType  direction,
-		     gpointer          data)
+                     GtkDirectionType  direction,
+                     gpointer          data)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (widget);
 
@@ -799,7 +823,7 @@ pt_waveviewer_get_follow_cursor (PtWaveviewer *self)
  */
 void
 pt_waveviewer_set_follow_cursor (PtWaveviewer *self,
-				 gboolean      follow)
+                                 gboolean      follow)
 {
 	g_return_if_fail (PT_IS_WAVEVIEWER (self));
 
@@ -853,7 +877,7 @@ size_allocate_cb (GtkWidget    *widget,
 
 static void
 make_widget_ready (PtWaveviewer *self,
-		   gboolean      ready)
+                   gboolean      ready)
 {
 	gint widget_width, left;
 
@@ -932,7 +956,7 @@ make_widget_ready (PtWaveviewer *self,
 
 static gboolean
 copy_wavedata (PtWaveviewer *self,
-	       PtWavedata   *data)
+               PtWavedata   *data)
 {
 	/* Copy array. If widget is not owner of its data, bad things can happen
 	   with bindings. */
@@ -965,7 +989,7 @@ copy_wavedata (PtWaveviewer *self,
  */
 void
 pt_waveviewer_set_wave (PtWaveviewer *self,
-			PtWavedata   *data)
+                        PtWavedata   *data)
 {
 	g_return_if_fail (PT_IS_WAVEVIEWER (self));
 
@@ -988,9 +1012,9 @@ pt_waveviewer_finalize (GObject *object)
 
 static void
 pt_waveviewer_get_property (GObject    *object,
-			    guint       property_id,
-			    GValue     *value,
-			    GParamSpec *pspec)
+                            guint       property_id,
+                            GValue     *value,
+                            GParamSpec *pspec)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (object);
 
@@ -1021,9 +1045,9 @@ pt_waveviewer_get_property (GObject    *object,
 
 static void
 pt_waveviewer_set_property (GObject      *object,
-			    guint	  property_id,
-			    const GValue *value,
-			    GParamSpec   *pspec)
+                            guint	  property_id,
+                            const GValue *value,
+                            GParamSpec   *pspec)
 {
 	PtWaveviewer *self = PT_WAVEVIEWER (object);
 
