@@ -1,4 +1,4 @@
-/* Copyright (C) Gabor Karsay 2017 <gabor.karsay@gmx.at>
+/* Copyright (C) Gabor Karsay 2017-2018 <gabor.karsay@gmx.at>
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as published
@@ -35,11 +35,10 @@ pt_player_fixture_set_up (PtPlayerFixture *fixture,
 	fixture->testplayer = NULL;
 	gchar    *path;
 	GFile    *file;
-	gchar    *testfile;
-	gchar    *testuri;
 	gboolean  success;
 
-	fixture->testplayer = pt_player_new (&error);
+	fixture->testplayer = pt_player_new ();
+	pt_player_setup_player (fixture->testplayer, &error);
 	g_assert_no_error (error);
 
 	path = g_test_build_filename (G_TEST_DIST, "data", "test1.ogg", NULL);
@@ -77,7 +76,8 @@ player_new (void)
 	PtPlayer *testplayer;
 	gdouble speed, volume;
 
-	testplayer = pt_player_new (&error);
+	testplayer = pt_player_new ();
+	pt_player_setup_player (testplayer, &error);
 	g_assert_no_error (error);
 	g_assert (PT_IS_PLAYER (testplayer));
 	g_object_get (testplayer,
@@ -99,7 +99,8 @@ player_open_fail (void)
 	GFile    *file;
 	gchar    *uri;
 
-	testplayer = pt_player_new (&error);
+	testplayer = pt_player_new ();
+	pt_player_setup_player (testplayer, &error);
 	g_assert_no_error (error);
 
 	success = pt_player_open_uri (testplayer, "foo", &error);
@@ -184,7 +185,8 @@ player_open_cancel (void)
 	data.loop = g_main_loop_new (context, FALSE);
 	data.res = NULL;
 
-	testplayer = pt_player_new (&error);
+	testplayer = pt_player_new ();
+	pt_player_setup_player (testplayer, &error);
 	g_assert_no_error (error);
 
 	testfile = g_test_build_filename (G_TEST_DIST, "data/test1.ogg", NULL);
@@ -198,10 +200,12 @@ player_open_cancel (void)
 	g_assert_false (success);
 	g_assert_error (error, G_IO_ERROR, G_IO_ERROR_CANCELLED);
 
+	g_error_free (error);
 	g_free (testfile);
 	g_free (testuri);
 	g_object_unref (testplayer);
 	g_main_loop_unref (data.loop);
+	g_object_unref (data.res);
 }
 
 static void
@@ -213,28 +217,53 @@ player_timestamps (PtPlayerFixture *fixture,
 	gboolean  valid;
 	
 	/* valid timestamps */
-	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.2#"));
-	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "0:01.2"));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.2#", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "0:01.2", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "(0:01.2)", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "[0:01.2]", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.21#", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01#", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#00:00:01.2#", FALSE));
+
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01-2#", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "0:01-2", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "(0:01-2)", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "[0:01-2]", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#0:01-21#", FALSE));
+	g_assert_true (pt_player_string_is_timestamp (fixture->testplayer, "#00:00:01-2#", FALSE));
+
+	/* single/wrong delimiters */
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.2", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "0:01.2#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "(0:01.2", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "[0:01.2)", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "@0:01.2", FALSE));
+
 	/* too many digits */
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.20#"));
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:001.2#"));
-	/* sec >= 60 */
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:71.2#"));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:001.2#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:01.200#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#000:01.2#", FALSE));
+	/* sec >= 60, min >= 60 */
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:60.2#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:71.2#", FALSE));
 	/* not enough digits */
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#:01.2#"));
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:1.2#"));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#:01.2#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:1.2#", FALSE));
 	/* wrong delimiters */
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0.01.2#"));
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:01:2#"));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "(0.01.2)", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0.01.2#", FALSE));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#0:01:2#", FALSE));
 	/* too big, not valid in the test file */
-	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#01:00.0#"));
+	g_assert_false (pt_player_string_is_timestamp (fixture->testplayer, "#01:00.0#", TRUE));
+
+	g_assert_cmpint (60200, ==, pt_player_get_timestamp_position (fixture->testplayer, "00:01:00-2", FALSE));
 
 	pt_player_jump_to_position (fixture->testplayer, 1000);
 	
 	timestamp = pt_player_get_timestamp (fixture->testplayer);
 	g_assert_nonnull (timestamp);
 
-	valid = pt_player_string_is_timestamp (fixture->testplayer, timestamp);
+	valid = pt_player_string_is_timestamp (fixture->testplayer, timestamp, TRUE);
 	g_assert_true (valid);
 
 	pt_player_jump_to_position (fixture->testplayer, 0);
@@ -281,7 +310,8 @@ player_volume_speed (PtPlayerFixture *fixture,
 	g_assert_cmpfloat (volume, ==, 0.7);
 
 	/* check bind property */
-	bind_player = pt_player_new (&error);
+	bind_player = pt_player_new ();
+	pt_player_setup_player (bind_player, &error);
 	g_assert_no_error (error);
 
 	g_object_bind_property (fixture->testplayer, "volume",
